// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
funcprot(0);
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

t2s=24*60*60;

function [x,y]=fOrt(t,param)
    sc=1.0E+9;
    // t in Tage
    t=t*t2s;
    R=param.r;
    Omega=param.omega;
    Phi0=param.phi0;
    
    x=(R/sc)*cos(Omega*t+Phi0);
    y=(R/sc)*sin(Omega*t+Phi0);
endfunction

function omega=fOmega(T) // Tage
    omega=(2*%pi)/(T*t2s);
endfunction

function phi0=fPhi0(x0,y0)
    phi0=atan(y0/x0);
endfunction

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

function plotBody(posx,posy,col)
  plot(posx,posy);  
  h = CL_g_select(gce(), "Polyline");
  h.line_mode = "off"; 
  h.mark_mode = "on"; 
  h.mark_style = 0; // round mark
  h.mark_background = col;
  h.mark_foreground = col;
  h.mark_size_unit = "point"; 
  h.mark_size = 5;
endfunction

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// Erde
paramE=[];
Re=149.67*1.0E+9; // [m]
Te=365.26; // [Tage]
X0e=25.338841*1.0E+9; // [m]
Y0e=-149.965279*1.0E+9; // [m]

paramE=[];
paramE.r=Re;
paramE.omega=fOmega(Te);
paramE.phi0=fPhi0(X0e,Y0e);

// Mars
Rm=227.7*1.0E+9; // [m]
Tm=686.98; // [Tage]
X0m=-115.281615*1.0E+9; // [m]     
Y0m=-197.167462*1.0E+9; // [m]

paramM=[];
paramM.r=Rm;
paramM.omega=fOmega(Tm);
paramM.phi0=fPhi0(X0m,Y0m);

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

scal="2014/04/01 12:00:00.000"; // <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

Start=-180;
Ende=180;
Tnull=0-Start+1
Anzahl=Ende-Start+1;
tData = linspace(Start,Ende,Anzahl);

cal_ref = CL_dat_str2cal(scal);
datestr = tokens(CL_dat_cal2str(cal_ref)); 

t0=CL_dat_cal2cjd(CL_dat_str2cal(scal));
posE=getBodyPos("Earth",t0);
posM=getBodyPos("Mars",t0);

paramE.phi0=fPhi0(posE(1),posE(2));
paramM.phi0=fPhi0(posM(1),posM(2));

[xe,ye]=fOrt(tData,paramE);
[xm,ym]=fOrt(tData,paramM);

xem=xm-xe;
yem=ym-ye;

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle=scf(11);
clf(my_handle,"reset");
a=gca();
a.isoview='on';

drawlater();

for Ix=1:10:Anzahl
    if Ix==1 then
        xset("color",color("gold"));
    else
        xset("color",color("gainsboro"));
    end
    
    xv(1)=xm(Ix);
    xv(2)=xe(Ix);
    yv(1)=ym(Ix);
    yv(2)=ye(Ix);
    xpoly(xv,yv);
end

xset("color",1);

plot2d(xm,ym,5);
plot2d(xe,ye,2);

plotBody(0,0,color("yellow1"));
plotBody(xe(1),ye(1),color("steelblue3"));
plotBody(xm(1),ym(1),color("indianred1"));
plotBody(xe(Tnull),ye(Tnull),color("steelblue3"));
plotBody(xm(Tnull),ym(Tnull),color("indianred1"));

a.labels_font_size=3;
a.x_label.font_size = 3;
a.y_label.font_size = 3;
a.title.font_size = 3;

xtitle (" Mars- und Erdumlauf  -  " + datestr(1) + ", Tage: " + string(Start) + " .. " + string(Ende),..
        " x (10^6 km) ", ..
        " y (10^6 km) " );

drawnow();







