// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
funcprot(0);
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

r2d=180/%pi;
d2r=%pi/180;

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

name="Mars";

scal="2014/04/01 12:00:00.000";

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

t0=CL_dat_cal2cjd(CL_dat_str2cal(scal));
t1=t0+1;

sf1=1;
sfs=1000;

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

function [azi,ele]=getpos(cbody,t,sf)
    pos_ICRS=CL_eph_de405(cbody,t,"Earth");
    pos_ICRS_sph=CL_co_car2sph(pos_ICRS);
    pos_ICRS_sph(3)=pos_ICRS_sph(3)*sf;
    pos_ICRS_scaled=CL_co_sph2car(pos_ICRS_sph);
    
    pos_ECI=CL_fr_convert("ICRS","ECI",t,pos_ICRS_scaled);
    
    pos_ECF=CL_fr_convert("ECI","ECF",t,pos_ECI);
    pos_ECF_sph=CL_co_car2sph(pos_ECF);
    azi=pos_ECF_sph(1);
    ele=pos_ECF_sph(2);
endfunction

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//
//[azi0_1,ele0_1]=getpos(t0,sf1);
//[azi0_s,ele0_s]=getpos(t0,sfs);
//
//[azi1_1,ele1_1]=getpos(t1,sf1);
//[azi1_s,ele1_s]=getpos(t1,sfs);
//
//disp("# Feste Position, 1 CJD-Tag Unterschied");
//disp("# Azimuth, Elevation in ECF");
//
//disp(CL_dat_cal2str(CL_dat_cjd2cal(t0)));
//disp(azi0_1*r2d);
//disp(ele0_1*r2d);
//
//disp(azi0_s*r2d);
//disp(ele0_s*r2d);
//
//disp(CL_dat_cal2str(CL_dat_cjd2cal(t1)));
//disp(azi1_1*r2d);
//disp(ele1_1*r2d);
//
//disp(azi1_s*r2d);
//disp(ele1_s*r2d);


// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

function plot_mark(azi,ele,col,fg,sz)
    
  plot(azi,ele,"o");
  
  e=gce();
  e.children.mark_background=col;
  e.children.mark_foreground=fg;
  e.children.mark_size=sz;
endfunction

function plotBody(posx,posy,col)
  plot(posx,posy);  
  h = CL_g_select(gce(), "Polyline");
  h.line_mode = "off"; 
  h.mark_mode = "on"; 
  h.mark_style = 0; // round mark
  h.mark_background = col;
  h.mark_foreground = col;
  h.mark_size_unit = "point"; 
  h.mark_size = 6;
endfunction

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

dur=[180,180];
tsteps=10;

t_start=t0-dur(1);
t_end=t0+dur(2);

if (tsteps>0)
  tv=t_start:tsteps:t_end;
end

nbTimes=size(tv,"c");

my_handle200=scf(200);
clf(my_handle200,"reset");
a=gca();
drawlater();

azimv=[];
elevv=[];

for tx=1:nbTimes 
    [azim,elev]=getpos(name,tv(tx),sf1); 
    azimv(tx)=azim*r2d;
    elevv(tx)=elev*r2d;
    
    if (tx==1) then
        col=color("yellow");
    elseif (azimv(tx)<azimv(tx-1)) then
        col=color("yellow");
    else
        col=color("orangered");
    end
    
    plot_mark(azimv(tx),elevv(tx),col,1,4);
end

plotBody(azimv(1),elevv(1),color("green3"));

for tx=1:nbTimes 
    if (tv(tx)==t0) then
        plotBody(azimv(tx),elevv(tx),color("steelblue3"));  
    end
end

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

dbElev=80;
db = [0,-dbElev;360,dbElev]; // data bounds
a.data_bounds = db;

CL_g_stdaxes(a);
a.grid = [0,0];
xgrid(color("grey"));

drawnow();

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

azimvr=azimv*d2r;
elevvr=elevv*d2r;

xv=cos(azimvr) .* cos(elevvr);
yv=sin(azimvr) .* cos(elevvr);
zv=sin(elevvr);

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle101=scf(101);
clf(my_handle101,"reset");
a=gca();
a.isoview='off';

nbazims=size(azimv,"r");

wdata=linspace(1,nbazims,nbazims);

subplot(211)
plot2d(wdata,azimv,color("steelblue3"));
subplot(212)
plot2d(wdata,elevv,color("steelblue3"));

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle102=scf(102);
clf(my_handle102,"reset");
a=gca();

subplot(2,1,1);
param3d(xv,yv,zv);
subplot(2,1,2);
param3d(xv,yv,zv,flag=[5,4],ebox=[-1,1,-1,1,-1,1]);















